<?php
// This plugin uses Metabox.io.  Since many plugins/sites may include Metabox, we only load it if they are not loaded.  To do this AFTER plugins, we run the include in plugins_loaded.
add_action('plugins_loaded', 'dcom_bib_load_plugins', 15);
// Load required plugins
function dcom_bib_load_plugins() {
	$included_plugin_dir = plugin_dir_path(__DIR__) . 'plugins';
	// Note, the loaders in Metabox will only run if there is a nead for them, therefore, we do not check here
	// Load MetaBox Library
	require_once $included_plugin_dir . '/meta-box/meta-box.php';
	// Load the Settings Panel Extension
	require_once $included_plugin_dir . '/mb-settings-page/mb-settings-page.php';
}

// Add a display filter to go to configuration from Plugins page
add_filter( 'plugin_action_links_' . $dcom_bib_plugin_file, 'dcom_bib_options_page_add_plugin_page_links' );
function dcom_bib_options_page_add_plugin_page_links ( $links ) {
	$base_id ='dcom_bib';
	$links[] = '<a href="' . admin_url( 'options-general.php?page='.$base_id) . '#tab-account">'.__('Configure', 'dcom_bib').'</a>';
	return $links;
}


add_filter ('mb_settings_pages', 'dcom_bib_options_page' );
function dcom_bib_options_page ($settings_pages) {
	$base_id ='dcom_bib';
	$prefix = '_dcom_bib_';
	$settings_pages[] = array(
		'id'				=> $base_id,
		'option_name'		=> $prefix.'configuration',
		'menu_title'		=> __('Debt.com Settings', 'dcom_bib'),
		'page_title'		=> __('Debt.com Settings for Business in a Box', 'dcom_bib'),
		'capability'		=> apply_filters('dcom_bib_required_capability', 'manage_options'),
		'parent'			=> 'options-general.php',
		'style'				=> 'no-boxes',
		'tabs'				=> array (
			'account'			=> __('Account Info', 'dcom_bib'),
			'docs'				=> __('Getting Started', 'dcom_bib'),
			'technical'			=> __('Technical Documentation', 'dcom_bib'),
			'contact'			=> __('Contact Debt.com', 'dcom_bib'),
		)
	);
	return $settings_pages;
}

add_filter('rwmb_meta_boxes', 'dcom_bib_options_page_metaboxes_accounts');
add_filter('rwmb_meta_boxes', 'dcom_bib_options_page_metaboxes_info');

function dcom_bib_get_enabled_verticles() {
	$default_vids = array(106, 108, 109, 110);
	$vid_to_label_mapping = array(
											106 => __('Credit Card Debt', 'dcom_bib'),
											108 => __('Credit Correction', 'dcom_bib'),
											109 => __('Student Loan Debt', 'dcom_bib'),
											110 => __('Tax Debt', 'dcom_bib'),
											111 => __('Collector Harassment', 'dcom_bib'),
											115 => __('Bankruptcy', 'dcom_bib')
							);
	$prefix = '_dcom_bib_';
	$bib_global = get_option($prefix.'configuration');
	if (!is_array($bib_global)) { $bib_global = array(); }
	
	$enabled_verticals = (is_array($bib_global) && array_key_exists($prefix.'enabledVids', $bib_global)) ? $bib_global[$prefix.'enabledVids'] : $default_vids;
	
	return array_intersect_key($vid_to_label_mapping, array_fill_keys($enabled_verticals, false));
}

function dcom_bib_options_page_metaboxes_accounts($meta_boxes) {
	$base_id ='dcom_bib';
	$prefix = '_dcom_bib_';

	$meta_boxes[] = array(
		'id'				=> $base_id . '_account',
		'title'				=> __('Account Info', 'dcom_bib'),
		'settings_pages'	=> $base_id,
		'tab'				=> 'account',
		'fields'			=> array(
			array(
				'id'			=> $prefix.'configuration_url',
				'name'			=> __('BIB URL', 'dcom_bib'),
				'type'			=> 'url',
				'desc'			=> __('URL Provided by your Account Representative', 'dcom_bib'),
				'class'			=> 'dcom-bib-configuration dcom-bib-configuration-first'
			),
			/*
			array(
				'id'			=> $prefix.'search_subid',
				'name'			=> __('Publisher ID', 'dcom_bib'),
				'type'			=> 'text',
				'desc'			=> __('ID is Provided by your Account Representative', 'dcom_bib'),
				'class'			=> 'dcom-bib-configuration'
			),
			*/
			array(
				'id'			=> $prefix.'enabledVids',
				'name'			=> __('Enabled Verticals', 'dcom_bib'),
				'type'			=> 'checkbox_list',
				'options'		=> array(
											106 => __('Credit Card Debt', 'dcom_bib'),
											108 => __('Credit Correction', 'dcom_bib'),
											109 => __('Student Loan Debt', 'dcom_bib'),
											110 => __('Tax Debt', 'dcom_bib') /*,
											111 => __('Collector Harassment', 'dcom_bib'),
											115 => __('Bankruptcy', 'dcom_bib') */
										),
				'select_all_none'	=> true,
				'std'			=> array(106, 108, 109, 110),
			),
			array(
				'id'			=> $prefix.'sub1',
				'name'			=> __('Sub1', 'dcom_bib'),
				'type'			=> 'text',
				'desc'			=> __('Tracking Parameter', 'dcom_bib').' #1',
				'class'			=> 'dcom-bib-configuration'
			),
			array(
				'id'			=> $prefix.'sub2',
				'name'			=> __('Sub2', 'dcom_bib'),
				'type'			=> 'text',
				'desc'			=> __('Tracking Parameter', 'dcom_bib').' #2',
				'class'			=> 'dcom-bib-configuration'
			),
			array(
				'id'			=> $prefix.'sub3',
				'name'			=> __('Sub3', 'dcom_bib'),
				'type'			=> 'text',
				'desc'			=> __('Tracking Parameter', 'dcom_bib').' #3',
				'class'			=> 'dcom-bib-configuration dcom-bib-configuration-last'
			)

		)
	);

	return $meta_boxes;
}

function dcom_bib_options_page_metaboxes_info($meta_boxes) {
	$base_id ='dcom_bib';

	// Add Documentation Panel
	$meta_boxes[] = array(
		'id'				=> $base_id.'_docs',
		'title'				=> __('Documentation', 'dcom_bib'),
		'settings_pages'	=> $base_id,
		'tab'				=> 'docs',
		'fields'			=> array(
			array(
				'type'				=> 'heading',
				'name'				=> __('Debt.com Business in a Box Plugin', 'dcom_bib'),
				'class'				=> 'dcom-bib-heading'
			),
/*
			array(
				'type'				=> 'custom_html',
				'std'				=> '<img class="dcom-bib-image-right" alt="'.__('Available Widgets', 'dcom_bib').'" src="'.plugins_url('/images/widgets-image.png', __DIR__) .'" />' .
									   '<p>'.__('Welcome!  Our plugin makes it easy to create new advertising channels.  It features:', 'dcom_bib').'</p>
										   <ul>
										   		<li>'.__('Debt Help Phone Number', 'dcom_bib').'</li>
										   		<li>'.__('Debt Help Lead Form', 'dcom_bib').'</li>
										   		<li>'.__('Financial Comparison Widgets', 'dcom_bib').'</li>
										   		<li>'.__('Financial Calculators', 'dcom_bib').'</li>
										   		<li>'.__('Financial Ad Units', 'dcom_bib').'</li>
										   </ul>'.
										  '<p>'.__('If you haven\'t received your Configuration URL and Publisher ID, contact our <a href="#tab-contact">Sales Team</a> to establish your account.', 'dcom_bib').'</p>'.
										  '<p>'.__('If you don\'t see your widgets, simply add your Configuration URL and Publisher ID to the Account Info Screen', 'dcom_bib').'</p>',
				'class'				=> 'dcom-bib-description'
			),
*/
            array(
                'type'				=> 'custom_html',
                'std'				=> '<img class="dcom-bib-image-right" alt="'.__('Available Widgets', 'dcom_bib').'" src="'.plugins_url('/images/widgets-image.png', __DIR__) .'" />' .
                    '<p>'.__('Welcome!  Our plugin makes it easy to create new advertising channels.  It features:', 'dcom_bib').'</p>
										   <ul>
										   		<li>'.__('Debt Help Phone Number', 'dcom_bib').'</li>
										   		<li>'.__('Debt Help Lead Form', 'dcom_bib').'</li>
										   </ul>'.
                    '<p>'.__('If you haven\'t received your Configuration URL, contact our <a href="#tab-contact">Sales Team</a> to establish your account.', 'dcom_bib').'</p>'.
                    '<p>'.__('If you don\'t see your widgets, simply add your Configuration URL to the Account Info Screen', 'dcom_bib').'</p>',
                'class'				=> 'dcom-bib-description'
            ),
			array(
				'type'				=> 'heading',
				'name'				=> __('Configuration Screen', 'dcom_bib'),
				'class'				=> 'dcom-bib-sub-heading'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> '<img alt="'.__('Account Configuration Screen', 'dcom_bib').'" src="'.plugins_url('/images/configuration-screen.png', __DIR__) .'" />',
				'class'				=> 'dcom-bib-image'
			),
			array(
				'type'				=> 'heading',
				'name'				=> __('Hotline Phone and Lead Form', 'dcom_bib'),
				'class'				=> 'dcom-bib-sub-heading'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> __('We recommend showing the Phone near the Top of Mobile Pages, and the Form in Sidebars.  We have included CSS classes, dcom-bib-mobile-only and dcom-bib-non-mobile,
										   but use of Theme Specific styling is recommended.', 'dcom_bib'),
				'class'				=> 'dcom-bib-description'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> '<img alt="'.__('Form Configuration', 'dcom_bib').'" src="'.plugins_url('/images/form-configuration.png', __DIR__) .'" />'."\n".
									   '<img alt="'.__('Phone Configuration', 'dcom_bib').'" src="'.plugins_url('/images/phone-configuration.png', __DIR__) .'" />',
				'class'				=> 'dcom-bib-image-stack'
			),
/*
			array(
				'type'				=> 'heading',
				'name'				=> __('Comparison Widget, Calculators, and Ad Units', 'dcom_bib'),
				'class'				=> 'dcom-bib-sub-heading'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> __('The Comparison Widget allows the user to search for appropriate products.  The Calculator and Ad Units are designed to drive your users to a comparison engine.', 'dcom_bib'),
				'class'				=> 'dcom-bib-description'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> __('If you choose to use Ad Units or Calculators, make sure to create a Page on your site with the appropriate comparison Shortcode and place the full URL in the destination field.', 'dcom_bib'),
				'class'				=> 'dcom-bib-description'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> '<img alt="'.__('Comparison Configuration', 'dcom_bib').'" src="'.plugins_url('/images/comparison-configuration.png', __DIR__) .'" />'."\n".
									   '<img alt="'.__('Calculator Configuration', 'dcom_bib').'" src="'.plugins_url('/images/calculator-configuration.png', __DIR__) .'" />',
				'class'				=> 'dcom-bib-image-stack'
			),
*/
			array(
				'type'				=> 'heading',
				'name'				=> __('Shortcodes', 'dcom_bib'),
				'class'				=> 'dcom-bib-sub-heading'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> __('Shortcodes allow you to include the utilities within the content instead of inside of a widget.  All fields are optional except
										   Destination URL for Calculators and Ad Units.  Those fields must include a URL to a page on your site featuring the corresponding
										   comparison Widget, either via Shortcode or Sidebar Widget.  All Shortcodes can be generated in the Visual Editors with corresponding
										   buttons.', 'dcom_bib'),
				'class'				=> 'dcom-bib-description'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> '<img alt="'.__('Visual Editor Buttons', 'dcom_bib').'" src="'.plugins_url('/images/editor-buttons.png', __DIR__) .'" />',
				'class'				=> 'dcom-bib-image'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> __('See the <a href="#tab-technical">Technical Documentations</a> for detailed shortcode documentation.', 'dcom_bib'),
				'class'				=> 'dcom-bib-description'
			),
			array(
				'type'				=> 'heading',
				'name'				=> __('Sub Ids', 'dcom_bib'),
				'class'				=> 'dcom-bib-sub-heading'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> __('Sub Ids help your segment your traffic for tracking, and you may use up to 3 Sub Ids for tracking.  You can set global values in the configuration page, or override them with shortcodes and widgets.  This will not affect compensation and get be left blank.', 'dcom_bib'),
				'class'				=> 'dcom-bib-description'
			),
		)
	);

	$meta_boxes[] = array(
		'id'				=> $base_id.'technical',
		'title'				=> __('Technical Documentation', 'dcom_bib'),
		'settings_pages'	=> $base_id,
		'tab'				=> 'technical',
		'fields'			=> array(
			array(
				'type'				=> 'heading',
				'name'				=> __('Debt.com BIB Technical User Guide', 'dcom_bib'),
				'class'				=> 'dcom-bib-heading'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> __('Our Plugin is designed to be turn-key with the included Widgets and Shortcodes.  For advanced users, you can fully customize your implementation to work best for your site.', 'dcom_bib'),
				'class'				=> 'dcom-bib-description'
			),
			array(
				'type'				=> 'heading',
				'name'				=> __('Sub IDs and Tracking', 'dcom_bib'),
				'class'				=> 'dcom-bib-sub-heading'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> __('Payment credit is based on your AID, set via Configuration URL, and your Publisher ID.  In addition to these account numbers, you have the availability of three Sub Ids for tracking, called Sub1, Sub2, and Sub3.  Your Account Representative will work with you to configure your Sub Ids for detailed tracking if you choose to use this feature.', 'dcom_bib'),
				'class'				=> 'dcom-bib-description'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> __('Sub IDs can be set globally or on each Widget/Shortcode.  If the Sub ID is set in both places, the local copy (Widget/Shortcode) will override the Global Settings.  For publishers with multiple sites, it may be advantageous to use Sub1 for the site, and Sub2/Sub3 for section/placement specific data.  Your use of Sub IDs is completely optional and is designed to help you fine tune your performance.', 'dcom_bib'),
				'class'				=> 'dcom-bib-description'
			),
			array(
				'type'				=> 'heading',
				'name'				=> __('Shortcodes', 'dcom_bib'),
				'class'				=> 'dcom-bib-sub-heading'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> __('Shortcodes can be generated in the Visual Editor for ease of use.  Those looking to manually configure them can use the full list of supported fields.', 'dcom_bib'),
				'class'				=> 'dcom-bib-description'
			),
			/*
			array(
				'type'				=> 'custom_html',
				'std'				=> '<h3>'.__('Lead Forms', 'dcom_bib').'</h3><ul>' .
											'<li><b>[lead_form before="" after="" configuration="" sub1="" sub2="" sub3=""]</b> - '.__('Draw a Lead Form', 'dcom_bib')."</li>\n" .
											'<li><b>[lead_phone before="" after="" configuration=""]</b> - '.__('Draw the Header Image and Phone', 'dcom_bib')."</li>\n" .
										'</ul><h3>'.__('Comparison Widgets', 'dcom_bib').'</h3><ul>' .
											'<li><b>[business_loans_comparison before="" after="" sub1="" sub2="" sub3=""]</b> - '.__('Business Loan Comparison Tool', 'dcom_bib')."</li>\n" .
											'<li><b>[identity_theft_comparison before="" after="" sub1="" sub2="" sub3=""]</b> - '.__('Identity Theft Product Comparison Tool', 'dcom_bib')."</li>\n" .
											'<li><b>[personal_loans_comparison before="" after="" sub1="" sub2="" sub3=""]</b> - '.__('Personal Loan Comparison Tool', 'dcom_bib')."</li>\n" .
											'<li><b>[student_loans_comparison before="" after="" sub1="" sub2="" sub3=""]</b> - '.__('Student Loan Comparison Tool', 'dcom_bib')."</li>\n" .
										'</ul><h3>'.__('Calculators', 'dcom_bib').'</h3><ul>' .
											'<li><b>[business_loans_calculator before="" after="" destination="" sub1="" sub2="" sub3=""]</b> - '.__('Business Loan Calculator Tool', 'dcom_bib')."</li>\n" .
											'<li><b>[personal_loans_calculator before="" after="" destination="" sub1="" sub2="" sub3=""]</b> - '.__('Personal Loan Calculator Tool', 'dcom_bib')."</li>\n" .
											'<li><b>[student_loans_calculator before="" after="" destination="" sub1="" sub2="" sub3=""]</b> - '.__('Student Loan Calculator Tool', 'dcom_bib')."</li>\n" .
										'</ul><h3>'.__('Ad Units', 'dcom_bib').'</h3><ul>' .
											'<li><b>[business_loans_ads before="" after="" destination="" sub1="" sub2="" sub3=""]</b> - '.__('Business Loan Ad Unit', 'dcom_bib')."</li>\n" .
											'<li><b>[identity_theft_ads before="" after="" destination="" sub1="" sub2="" sub3=""]</b> - '.__('Identity Theft Ad Unit', 'dcom_bib')."</li>\n" .
											'<li><b>[personal_loans_ads before="" after="" destination="" sub1="" sub2="" sub3=""]</b> - '.__('Personal Loan Ad Unit', 'dcom_bib')."</li>\n" .
											'<li><b>[student_loans_ads before="" after="" destination="" sub1="" sub2="" sub3=""]</b> - '.__('Student Loan Ad Unit', 'dcom_bib')."</li>\n" .
										"</ul>",
				'class'				=> 'dcom-bib-technical-description'
			),
			*/
            array(
                'type'				=> 'custom_html',
                'std'				=> '<h3>'.__('Lead Forms', 'dcom_bib').'</h3><ul>' .
                    '<li><b>[lead_form before="" after="" configuration="" sub1="" sub2="" sub3=""]</b> - '.__('Draw a Lead Form', 'dcom_bib')."</li>\n" .
                    '<li><b>[lead_phone before="" after="" configuration=""]</b> - '.__('Draw the Header Image and Phone', 'dcom_bib')."</li>\n" .
                    "</ul>",
                'class'				=> 'dcom-bib-technical-description'
            ),
/*
            array(
				'type'				=> 'custom_html',
				'std'				=> __('The only required field is destination for the Calculator and Ad Units Shortcodes.  The destination field takes a full URL, not a relative URL.  When the user uses the calculator or clicks on an Ad they will be directed to the Destination URL.  The Page or Post included in the Destination should feature the corresponding Comparison Short Code.  You can further customize or optimize that page for user experience or search engine optimization.  The information in the calculator will be carried to the resulting page.', 'dcom_bib'),
				'class'				=> 'dcom-bib-description'
			),
*/
			array(
				'type'				=> 'heading',
				'name'				=> __('Shortcode Field Descriptions', 'dcom_bib'),
				'class'				=> 'dcom-bib-sub-heading'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> '<ul>' .
											'<li><b>destination</b> -' . __('Destination URL to a Page Featuring the Comparison Widget', 'dcom_bib') . "</li>\n" .
											'<li><b>before</b> -' . __('HTML Outputted Before the DIV', 'dcom_bib') . "</li>\n" .
											'<li><b>after</b> -' . __('HTML Outputted After the DIV', 'dcom_bib') . "</li>\n" .
											'<li><b>configuration</b> -' . __('Alternative Configuration URL provided by Account Representative for specialized form versions.', 'dcom_bib') . "</li>\n" .
											'<li><b>sub1</b> -' . __('First Tracking DIV passed as S3 or C1 for reporting', 'dcom_bib') . "</li>\n" .
											'<li><b>sub2</b> -' . __('First Tracking DIV passed as S4 or C2 for reporting', 'dcom_bib') . "</li>\n" .
											'<li><b>sub3</b> -' . __('First Tracking DIV passed as S5 or C3 for reporting', 'dcom_bib') . "</li>\n" .
										'</ul>',
				'class'				=> 'dcom-bib-technical-description'
			),
			array(
				'type'				=> 'heading',
				'name'				=> __('Template Integration', 'dcom_bib'),
				'class'				=> 'dcom-bib-sub-heading'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> 'The preferred method is to use do_shortcode() with the corresponding Shortcode.  While it is possible to reference the underlying drawing PHP function, using the Shortcode prevents problems if the Program IDs are later changed.  For example:',
				'class'				=> 'dcom-bib-description'
			),
			/*
			array(
				'type'				=> 'custom_html',
				'std'				=>  '<code>'.htmlentities("<?php if (function_exists('dcom_draw_bib_form')) { do_shortcode('[lead_form sub2=\"credit-card-debt-education\"]'); } ?>").'</code><br />' .
										'<code>'.htmlentities("<?php if (function_exists('dcom_draw_bib_phone')) { do_shortcode('[lead_phone]'); } ?>").'</code><br />' .
										'<code>'.htmlentities("<?php if (function_exists('dcom_comparison_shortcode_func')) { do_shortcode('[personal_loans_comparison sub1=\"comparison-page\"]'); } ?>").'</code><br />' .
										'<code>'.htmlentities("<?php if (function_exists('dcom_calculator_ad_shortcode_func')) { do_shortcode('[personal_loans_ads destination=\"https://www.site.com/personal-loans-compared/\"]'); } ?>").'</code><br />' ,
				'class'				=> 'dcom-bib-technical-description'
			),
			*/
            array(
                'type'				=> 'custom_html',
                'std'				=>  '<code>'.htmlentities("<?php if (function_exists('dcom_draw_bib_form')) { do_shortcode('[lead_form sub2=\"credit-card-debt-education\"]'); } ?>").'</code><br />' .
                                        '<code>'.htmlentities("<?php if (function_exists('dcom_draw_bib_phone')) { do_shortcode('[lead_phone]'); } ?>").'</code><br />' ,
                'class'				=> 'dcom-bib-technical-description'
            ),
		),
	);

	// Add Contact Panel
	$meta_boxes[] = array(
		'id'				=> $base_id.'_contact',
		'title'				=> __('Contact Debt.com', 'dcom_bib'),
		'settings_pages'	=> $base_id,
		'tab'				=> 'contact',
		'fields'			=> array(
			array(
				'type'				=> 'custom_html',
				'std'				=>  '<a href="https://www.debt.com/our-story/partner-with-us/publishers-and-bloggers/" title="Publishers and Bloggers">' .
										'<img alt="'.__('Debt.com Business in a Box', 'dcom_bib').'" src="'.plugins_url('/assets/banner-1544x500.jpg', __DIR__).'">' .
										'</a>',
				'class'				=> 'dcom-bib-banner-image'
			),
			array(
				'type'				=> 'heading',
				'name'				=> __('Contact Debt.com', 'dcom_bib'),
				'class'				=> 'dcom-bib-heading'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> __('Business in a Box Accounts are subject to our <a href="https://www.debt.com/our-story/partner-with-us/code-ethics/">Code Of Ethics</a>' .
										  ', and all partners must be approved.  You can reach us by email or through our website.', 'dcom_bib'),
				'class'				=> 'dcom-bib-description'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> __('To establish an account', 'dcom_bib').': <a href="mailto:bibsales@debt.com">bibsales@debt.com</a>.' . "\n<br>\n" .
									   __('For technical support', 'dcom_bib').': <a href="mailto:bibsupport@debt.com">bibsupport@debt.com</a>.',
				'class'				=> 'dcom-bib-description'
			),
			array(
				'type'				=> 'custom_html',
				'std'				=> __('For More Information, view our <a href="https://www.debt.com/our-story/partner-with-us/publishers-and-bloggers/" title="Publishers and Bloggers">Publishers and Bloggers</a> page', 'dcom_bib'),
				'class'				=> 'dcom-bib-description'  
			)
		)
	);

	return $meta_boxes;
}

add_action('admin_enqueue_scripts', 'dcom_bib_admin_script_register');
add_action('admin_enqueue_scripts', 'dcom_bib_admin_script_enqueue', 20);

function dcom_bib_admin_script_register() {
	wp_register_style('bib-admin', plugins_url('css/bib_admin.css', __DIR__), array('rwmb', 'mb-settings-page'), '2.1.1');
}
function dcom_bib_admin_script_enqueue() {
	wp_enqueue_style('bib-admin');
}