(function($) {
    tinymce.create('tinymce.plugins.Dcom_TinyMCE', {
        /**
         * Initializes the plugin, this will be executed after the plugin has been created.
         * This call is done before the editor instance has finished it's initialization so use the onInit event
         * of the editor instance to intercept that event.
         *
         * @param {tinymce.Editor} ed Editor instance that the plugin is initialized in.
         * @param {string} url Absolute URL to where the plugin is located.
         */
        init : function(ed, url) {
                var pluginUrl = url.substring(0, url.lastIndexOf('/') + 1);
                ed.addButton('dcom_leads', {
                    title : 'Leads',
                    cmd: 'dcom_leads',
                    image : pluginUrl + '/images/form.png'
                });

                ed.addButton('dcom_comparison', {
                    title : 'Comparisons',
                    cmd: 'dcom_comparisons',  // comparison.jpg
                    image : pluginUrl + '/images/comparison.jpg'
                });

                ed.addButton('dcom_calculators', {
                    title : 'Calculators and Ad Units',
                    cmd: 'dcom_calculators',
                    image : pluginUrl + '/images/calculator.png'
                });

                ed.addCommand('dcom_leads', function() {
                    ed.windowManager.open({
                        title: 'Configure Lead Shortcode',
                        width: 600,
                        height: 240,
                        inline: 1,
                        id: 'dcom-leads-insert-dialog',
                        onsubmit: function(e) {
                            shortcode = '[' + e.data.shortcode;
                            if (e.data.shortcode == 'lead_form') {
                                if (e.data.sub1) { shortcode += ' sub1="'+e.data.sub1+'"'; }
                                if (e.data.sub2) { shortcode += ' sub2="'+e.data.sub2+'"'; }
                                if (e.data.sub3) { shortcode += ' sub3="'+e.data.sub3+'"'; }
                            }
                            if (e.data.configuration) { shortcode += ' configuration="'+e.data.configuration+'"'; }
                            shortcode += ']';
                            ed.execCommand('mceInsertContent', 0, shortcode);
                        },
                        body: [
                            {
                                type: 'listbox',
                                name: 'shortcode',
                                label: 'Form Type:',
                                values: [
                                    { text: 'Phone', value: 'lead_phone'},
                                    { text: 'Lead Form', value: 'lead_form'}
                                ] /* of values */
                            },
                            {   type: 'textbox', name: 'sub1', label: 'Sub 1', tooltip: 'Form Only' },
                            {   type: 'textbox', name: 'sub2', label: 'Sub 2', tooltip: 'Form Only' },
                            {   type: 'textbox', name: 'sub3', label: 'Sub 3', tooltip: 'Form Only' },
                            {   type: 'textbox', name: 'configuration', label: 'Configuration URL', tooltip: 'Normally Blank' },
                        ], /* End of Body */
                        buttons: [
                                { /* Begin Insert Button */
                                    text: 'Insert',
                                    id: 'dcom-leads-insert-button',
                                    class: 'insert dcom-bib-insert',
                                    onclick: 'submit'
                                }, /* End Insert Button */
                                { /* Begin Cancel Button */
                                    text: 'Cancel',
                                    id: 'dcom-leads-cancel-button',
                                    class: 'cancel dcom-bib-cancel',
                                    onclick: 'close'

                                }, /* End Cancel Button */
                        ],
                    }); /* End open command */
                }); /* End addCommand dcom_leads */
/*
                ed.addCommand('dcom_comparisons', function() {
                    ed.windowManager.open({
                        title: 'Configure Comparison Shortcode',
                        width: 600,
                        height: 200,
                        inline: 1,
                        id: 'dcom-comparisons-insert-dialog',
                        onsubmit: function(e) {
                            shortcode = '[' + e.data.shortcode;
                            if (e.data.sub1) { shortcode += ' sub1="'+e.data.sub1+'"'; }
                            if (e.data.sub2) { shortcode += ' sub2="'+e.data.sub2+'"'; }
                            if (e.data.sub3) { shortcode += ' sub3="'+e.data.sub3+'"'; }
                            shortcode += ']';
                            ed.execCommand('mceInsertContent', 0, shortcode);
                        },
                        body: [
                            {
                                type: 'listbox',
                                name: 'shortcode',
                                label: 'Form Type:',
                                values: [
                                    { text: 'Business Loans', value: 'business_loans_comparison'},
                                    { text: 'Identity Theft', value: 'identity_theft_comparison'},
                                    { text: 'Personal Loans', value: 'personal_loans_comparison'},
                                    { text: 'Student Loans', value: 'student_loans_comparison'},
                                ] // of values
                            },
                            {   type: 'textbox', name: 'sub1', label: 'Sub 1'},
                            {   type: 'textbox', name: 'sub2', label: 'Sub 2'},
                            {   type: 'textbox', name: 'sub3', label: 'Sub 3'}
                        ], // End of Body
                        buttons: [
                                { // Begin Insert Button
                                    text: 'Insert',
                                    id: 'dcom-leads-insert-button',
                                    class: 'insert dcom-bib-insert',
                                    onclick: 'submit'
                                }, //  End Insert Button
                                { // Begin Cancel Button
                                    text: 'Cancel',
                                    id: 'dcom-leads-cancel-button',
                                    class: 'cancel dcom-bib-cancel',
                                    onclick: 'close'

                                }, // End Cancel Button
                        ],
                    }); // End open command
                });
                ed.addCommand('dcom_calculators', function() {
                    ed.windowManager.open({
                        title: 'Configure Calculator and Ad Units Shortcode',
                        width: 600,
                        height: 200,
                        inline: 1,
                        id: 'dcom-calculators-insert-dialog',
                        onsubmit: function(e) {
                            shortcode = '[' + e.data.shortcode;
                            if (e.data.sub1) { shortcode += ' sub1="'+e.data.sub1+'"'; }
                            if (e.data.sub2) { shortcode += ' sub2="'+e.data.sub2+'"'; }
                            if (e.data.sub3) { shortcode += ' sub3="'+e.data.sub3+'"'; }
                            shortcode += ']';
                            ed.execCommand('mceInsertContent', 0, shortcode);
                        },
                        body: [
                            {
                                type: 'listbox',
                                name: 'shortcode',
                                label: 'Form Type:',
                                values: [
                                    { text: 'Business Loans Calculator', value: 'business_loans_calculator'},
                                    { text: 'Personal Loans Calculator', value: 'personal_loans_calculator'},
                                    { text: 'Student Loans Calculator', value: 'student_loans_calculator'},
                                    { text: 'Business Loans Ad Unit', value: 'business_loans_ads'},
                                    { text: 'Identity Theft Ad Unit', value: 'identity_theft_ads'},
                                    { text: 'Personal Loans Ad Unit', value: 'personal_loans_ads'},
                                    { text: 'Student Loans Ad Unit', value: 'student_loans_ads'},

                                ] // of values
                            },
                            {   type: 'textbox', name: 'sub1', label: 'Sub 1'},
                            {   type: 'textbox', name: 'sub2', label: 'Sub 2'},
                            {   type: 'textbox', name: 'sub3', label: 'Sub 3'},
                            {   type: 'textbox', name: 'destination', label: 'Destination URL', tooltip: 'REQUIRED Full URL of Page with Comparison Shortcode' },
                        ], // End of Body
                        buttons: [
                                { // Begin Insert Button
                                    text: 'Insert',
                                    id: 'dcom-leads-insert-button',
                                    class: 'insert dcom-bib-insert',
                                    onclick: 'submit'
                                }, // End Insert Button
                                { // Begin Cancel Button
                                    text: 'Cancel',
                                    id: 'dcom-leads-cancel-button',
                                    class: 'cancel dcom-bib-cancel',
                                    onclick: 'close'

                                }, // End Cancel Button
                        ],
                    }); // End open command
                });
*/
        },
 
        /**
         * Creates control instances based in the incomming name. This method is normally not
         * needed since the addButton method of the tinymce.Editor class is a more easy way of adding buttons
         * but you sometimes need to create more complex controls like listboxes, split buttons etc then this
         * method can be used to create those.
         *
         * @param {String} n Name of the control to create.
         * @param {tinymce.ControlManager} cm Control manager to use inorder to create new control.
         * @return {tinymce.ui.Control} New control instance or null if no control was created.
         */
        createControl : function(n, cm) {
            return null;
        },
 
        /**
         * Returns information about the plugin as a name/value array.
         * The current keys are longname, author, authorurl, infourl and version.
         *
         * @return {Object} Name/value array containing information about the plugin.
         */
        getInfo : function() {
            return {
                longname : 'Debt.com BIB Plugins',
                author : 'Debt.com',
                authorurl : 'https://www.debt.com/',
                infourl : 'https://www.debt.com/',
                version : "3.0"
            };
        }
    });
 
    // Register plugin
    tinymce.PluginManager.add( 'dcom_tinymce', tinymce.plugins.Dcom_TinyMCE );
})(jQuery);